@@ -6,7 +6,7 @@ from PySide.QtGui import *
 from PySide.QtMaemo5 import QMaemo5ValueButton, QMaemo5ListPickSelector
 
 # Some global variables
-GnGeoGuiVersion = "0.0.5-7"
+GnGeoGuiVersion = "0.0.5-9"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -134,6 +134,15 @@ class Ui_MainWindow(QMainWindow):
 	for Game in Games:
         	self.combo.addItem(Game)
 
+	self.combo.setEditable(True)
+	self.combo.lineEdit().setAlignment(Qt.AlignCenter)  
+	self.combo.lineEdit().setReadOnly(True)
+	self.combo.lineEdit().setAlignment(Qt.AlignCenter)  
+	for x in range(0,self.combo.count()):
+		self.combo.setItemData(x, Qt.AlignCenter, Qt.TextAlignmentRole)
+	self.combo.setEditable(False)
+
+
 	# Define menubar
 	aboutAction = QAction( '&About', self)
         aboutAction.triggered.connect(self.slotAbout)
@@ -333,7 +342,7 @@ class ConfigWindow(QMainWindow):
 		self.joystickPushButton.setChecked(True)
 	# system
 	self.systemButton = QMaemo5ValueButton("system")
-        self.systemButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.systemButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
 	model = QStandardItemModel(0,0) # (rows, columns)
 	systems = self.listDefaultFirst("system",['arcade','home','unibios'])
 	for sysType in systems:
@@ -351,7 +360,7 @@ class ConfigWindow(QMainWindow):
 
 	# country
 	self.regionButton = QMaemo5ValueButton("region")
-        self.regionButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.regionButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
 	modelc = QStandardItemModel(0,0) # (rows, columns)
 	countries = self.listDefaultFirst("country",['japan', 'usa', 'europe'])
 	for Location in countries:
@@ -363,7 +372,7 @@ class ConfigWindow(QMainWindow):
         grid.addWidget(self.regionButton,4,2)
 	# effect
 	self.effectButton = QMaemo5ValueButton("effect")
-        self.effectButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.effectButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
 	modele = QStandardItemModel(0,0) # (rows, columns)
 	effects = self.listDefaultFirst("effect",['none', 'scanline', 'scanline50', 'scale2x',
 	                                          'scale3x', 'scale4x', 'scale2x50', 'scale2x75',
@@ -402,7 +411,7 @@ class ConfigWindow(QMainWindow):
 	grid.addWidget(self.M68KSpinBox, 6,3)
 	# Joystick device P1 (/dev/input/js?)
 	self.joyp1devButton = QMaemo5ValueButton("P1 joystick device")
-        self.joyp1devButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.joyp1devButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
 	modelp1dev = QStandardItemModel(0,0) # (rows, columns)
 	JoyP1devs = self.listDefaultFirst("p1joydev",['0', '1', '2', '3'])
 	for JoyP1dev in JoyP1devs:
@@ -414,7 +423,7 @@ class ConfigWindow(QMainWindow):
         grid.addWidget(self.joyp1devButton,7,1)
 	# Joystick device P2 (/dev/input/js?)
 	self.joyp2devButton = QMaemo5ValueButton("P2 joystick device")
-        self.joyp2devButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
+        self.joyp2devButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
 	modelp2dev = QStandardItemModel(0,0) # (rows, columns)
 	JoyP2devs = self.listDefaultFirst("p2joydev",['0', '1', '2', '3'])
 	for JoyP2dev in JoyP2devs:
